## 1.4.0 - 2025-03-11

### ✨ Added

- [#1285](https://github.com/edgarrmondragon/citric/issues/1285) The `additional_options` parameter for the `export_responses` and `save_responses` methods of the RPC client
